Stan Math Library: stan/math/prim/mat/err/constraint_tolerance.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

constraint_tolerance.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_MAT_ERR_CONSTRAINT_TOLERANCE_HPP
2 #define STAN_MATH_PRIM_MAT_ERR_CONSTRAINT_TOLERANCE_HPP
3
4 namespace stan {
5 namespace math {
6
11 const double CONSTRAINT_TOLERANCE = 1E-8;
12
13 }
14 }
15 #endif
stan
Definition: log_sum_exp.hpp:8
stan::math::CONSTRAINT_TOLERANCE
const double CONSTRAINT_TOLERANCE
The tolerance for checking arithmetic bounds In rank and in simplexes.
Definition: constraint_tolerance.hpp:11
stan::math::E
const double E
The base of the natural logarithm, .
Definition: constants.hpp:15

[ Stan Home Page ] © 2011–2016, Stan Development Team.